==> clash-ghc-1.4.3-6-x86_64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-ghc
version:              1.4.3
visibility:           public
id:                   clash-ghc-1.4.3-HCBx8PFwSWvBeo1DXF1Oe
key:                  clash-ghc-1.4.3-HCBx8PFwSWvBeo1DXF1Oe
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  5092805d06aced55fe6cb9b713481808
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.UI Clash.GHCi.UI.Info Clash.GHCi.UI.Monad
    Clash.GHCi.UI.Tags Clash.GHC.ClashFlags Clash.GHC.GHC2Core
    Clash.GHC.LoadInterfaceFiles Clash.GHC.Util Paths_clash_ghc
    Clash.GHCi.Leak Clash.GHCi.Util

import-dirs:          /usr/lib/ghc-9.0.1/site-local/clash-ghc-1.4.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/clash-ghc-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/clash-ghc-1.4.3
hs-libraries:         HSclash-ghc-1.4.3-HCBx8PFwSWvBeo1DXF1Oe
depends:
    Cabal-3.4.0.0 array-0.5.4.0 base-4.15.0.0
    bifunctors-5.5.11-4L4MwgXpzLKJB3nUQXjoLA bytestring-0.10.12.1
    clash-lib-1.4.3-CJ8mjSF3N323G2wNKVXVk5
    clash-prelude-1.4.3-GnnCcTIw1yn1fk0zJpgZ9O
    concurrent-supply-0.1.8-51LJTwIpzmA6AmpuvNoKXy containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.1 exceptions-0.10.4
    extra-1.7.9-IPx7nrY9PGCFR1u9hKqJoo filepath-1.4.2.1 ghc-9.0.1
    ghc-bignum-1.0 ghc-boot-9.0.1 ghc-prim-0.7.0
    ghc-typelits-extra-0.4.3-5ckZRA3MgvpIbGZoyNM1Nr
    ghc-typelits-knownnat-0.7.6-1zbSBSYYheTFOdX24Ih4hx
    ghc-typelits-natnormalise-0.7.6-DZvXJnvaNky3SIaWw9Dt7V ghci-9.0.1
    hashable-1.3.3.0-BjQXPnRjTz0I5yXUcLzcAY haskeline-0.8.1.0
    lens-5.0.1-CkMzM1Gep2n4WEseqiwBkf mtl-2.2.2
    primitive-0.7.2.0-CcLwwKTNpeU15LbVKU3jRF process-1.6.11.0
    reflection-2.1.6-4d6iwlHPb428q1oO1HEWIf
    split-0.2.3.4-lGGgEjegWBLt5hlmeoIpy template-haskell-2.17.0.0
    text-1.2.4.1 time-1.9.3 transformers-0.5.6.2
    uniplate-1.6.13-BoqXNa9sJ0L6LyPWaDdXv unix-2.7.2.2
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR
    utf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> clash-ghc-1.4.3-11-x86_64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-ghc
version:              1.4.3
visibility:           public
id:                   clash-ghc-1.4.3-1RnOZWRATgiIRaoBkCikfN
key:                  clash-ghc-1.4.3-1RnOZWRATgiIRaoBkCikfN
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  13f38c4b1d6e3a8be32906c35f8f40ff
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.UI Clash.GHCi.UI.Info Clash.GHCi.UI.Monad
    Clash.GHCi.UI.Tags Clash.GHC.ClashFlags Clash.GHC.GHC2Core
    Clash.GHC.LoadInterfaceFiles Clash.GHC.Util Paths_clash_ghc
    Clash.GHCi.Leak Clash.GHCi.Util

import-dirs:          /usr/lib/ghc-9.0.1/site-local/clash-ghc-1.4.3
library-dirs:         /usr/lib/ghc-9.0.1/site-local/clash-ghc-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/clash-ghc-1.4.3
hs-libraries:         HSclash-ghc-1.4.3-1RnOZWRATgiIRaoBkCikfN
depends:
    Cabal-3.4.0.0 array-0.5.4.0 base-4.15.0.0
    bifunctors-5.5.11-4L4MwgXpzLKJB3nUQXjoLA bytestring-0.10.12.1
    clash-lib-1.4.3-LFNIvEOtJM7G5CPwr8OKgn
    clash-prelude-1.4.3-J4t5GGzK3fgITweiN2Ai5c
    concurrent-supply-0.1.8-51LJTwIpzmA6AmpuvNoKXy containers-0.6.4.1
    deepseq-1.4.5.0 directory-1.3.6.1 exceptions-0.10.4
    extra-1.7.10-BvdTl6cjCa8NOGkBoNpwW filepath-1.4.2.1 ghc-9.0.1
    ghc-bignum-1.0 ghc-boot-9.0.1 ghc-prim-0.7.0
    ghc-typelits-extra-0.4.3-5ckZRA3MgvpIbGZoyNM1Nr
    ghc-typelits-knownnat-0.7.6-1zbSBSYYheTFOdX24Ih4hx
    ghc-typelits-natnormalise-0.7.6-DZvXJnvaNky3SIaWw9Dt7V ghci-9.0.1
    hashable-1.3.3.0-BjQXPnRjTz0I5yXUcLzcAY haskeline-0.8.1.0
    lens-5.0.1-DYRBsqEWMrFDKEoMThJtK4 mtl-2.2.2
    primitive-0.7.2.0-CcLwwKTNpeU15LbVKU3jRF process-1.6.11.0
    reflection-2.1.6-4d6iwlHPb428q1oO1HEWIf
    split-0.2.3.4-lGGgEjegWBLt5hlmeoIpy template-haskell-2.17.0.0
    text-1.2.4.1 time-1.9.3 transformers-0.5.6.2
    uniplate-1.6.13-BoqXNa9sJ0L6LyPWaDdXv unix-2.7.2.2
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR
    utf8-string-1.0.2-FSV4F6pxd5y7PjtRkbEpDf
    vector-0.12.3.0-7AyAfn90uRLJwvulX46pQG

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
